@@ -45,11 +45,11 @@ def validate():
     """Validate a metrics layer project, internally, without hitting the database"""
     profile = SeedMetricsLayer.get_profile()
     metrics_layer = SeedMetricsLayer._init_profile(profile)
-    errors = metrics_layer.config.project.validate()
+    errors = metrics_layer.project.validate()
 
     if len(errors) == 0:
-        n_explores = len(metrics_layer.config.project.explores())
-        echo(f"Project passed (checked {n_explores} explore{'s' if n_explores > 1 else ''})!")
+        n_models = len(metrics_layer.project.models())
+        echo(f"Project passed (checked {n_models} model{'s' if n_models > 1 else ''})!")
     else:
         echo(f"Found {len(errors)} error{'s' if len(errors)> 1 else ''} in the project:\n")
         for error in errors:
@@ -77,7 +77,7 @@ def debug():
     python_path = sys.executable
     echo(f"python path: {python_path}")
 
-    profiles_path = metrics_layer.config.profiles_path
+    profiles_path = metrics_layer.profiles_path
     if profiles_path:
         echo(f"Using profiles.yml file at {profiles_path}")
     else:
@@ -85,7 +85,7 @@ def debug():
 
     # Configuration:
     echo(f"\nConfiguration:")
-    if metrics_layer.config.profiles_path:
+    if metrics_layer.profiles_path:
         echo(f"  profiles.yml file OK found and valid", color="green")
     else:
         echo(f"  profiles.yml file Not found", color="red")
@@ -96,7 +96,7 @@ def debug():
     echo(f"  git [{git_status}]", color="green" if "OK" in git_status else "red")
 
     # Connection:
-    connections = metrics_layer.config.connections()
+    connections = metrics_layer.list_connections()
     echo(f"\nConnection{'s' if len(connections) > 1 else ''}:")
     for connection in connections:
         for key, value in connection.printable_attributes().items():
@@ -116,17 +116,12 @@ def debug():
 
 
 @cli_group.command("list")
-@click.option(
-    "--explore",
-    default=None,
-    help="The name of the explore (only applicable for fields, dimensions, metrics, and views)",
-)
 @click.option(
     "--view", default=None, help="The name of the view (only applicable for fields, dimensions, and metrics)"
 )
 @click.option("--show-hidden", is_flag=True, help="Set this flag if you want to see hidden fields")
 @click.argument("type")
-def list_(type, explore, view, show_hidden):
+def list_(type, view, show_hidden):
     """List attributes in a metrics layer project,
     i.e. models, connections, explores, views, fields, metrics, dimensions"""
     profile = SeedMetricsLayer.get_profile()
@@ -137,34 +132,26 @@ def list_(type, explore, view, show_hidden):
         items = metrics_layer.list_models(names_only=True)
     elif type == "connections":
         items = metrics_layer.list_connections(names_only=True)
-    elif type == "explores":
-        items = metrics_layer.list_explores(names_only=True, show_hidden=show_hidden)
     elif type == "views":
-        items = metrics_layer.list_views(names_only=True, explore_name=explore, show_hidden=show_hidden)
+        items = metrics_layer.list_views(names_only=True)
     elif type == "fields":
-        items = metrics_layer.list_fields(
-            names_only=True, view_name=view, explore_name=explore, show_hidden=show_hidden
-        )
+        items = metrics_layer.list_fields(names_only=True, view_name=view, show_hidden=show_hidden)
     elif type == "dimensions":
-        items = metrics_layer.list_dimensions(
-            names_only=True, view_name=view, explore_name=explore, show_hidden=show_hidden
-        )
+        items = metrics_layer.list_dimensions(names_only=True, view_name=view, show_hidden=show_hidden)
     elif type == "metrics":
-        items = metrics_layer.list_metrics(
-            names_only=True, view_name=view, explore_name=explore, show_hidden=show_hidden
-        )
+        items = metrics_layer.list_metrics(names_only=True, view_name=view, show_hidden=show_hidden)
     elif type == "profiles":
-        if profile:
-            items = metrics_layer.config.get_all_profiles(names_only=True)
-        else:
-            from metrics_layer.core.parse import MetricsLayerConfiguration
+        # if profile:
+        items = metrics_layer.get_all_profiles(names_only=True)
+        # else:
+        #     from metrics_layer.core.parse import MetricsLayerConfiguration
 
-            default_directory = MetricsLayerConfiguration.get_metrics_layer_directory() + "profiles.yml"
-            items = MetricsLayerConfiguration.get_all_profiles(default_directory, names_only=True)
+        #     default_directory = MetricsLayerConfiguration.get_metrics_layer_directory() + "profiles.yml"
+        #     items = MetricsLayerConfiguration.get_all_profiles(default_directory, names_only=True)
     else:
         click.echo(
             f"Could not find the type {type}, please use one of the options: "
-            "models, connections, explores, views, fields, metrics, dimensions"
+            "models, connections, views, fields, metrics, dimensions"
         )
     if items:
         click.echo(f"Found {len(items)} {type if len(items) > 1 else type[:-1]}:\n")
@@ -180,16 +167,11 @@ def list_(type, explore, view, show_hidden):
     "--type",
     help="The type of object to show. One of: model, connection, explore, view, field, metric, dimension",  # noqa
 )
-@click.option(
-    "--explore",
-    default=None,
-    help="The name of the explore (only applicable for fields, dimensions, metrics, and views)",
-)
 @click.option(
     "--view", default=None, help="The name of the view (only applicable for fields, dimensions, and metrics)"
 )
 @click.argument("name")
-def show(type, name, explore, view):
+def show(type, name, view):
     """Show information on an attribute in a metrics layer project, by name"""
     profile = SeedMetricsLayer.get_profile()
     metrics_layer = SeedMetricsLayer._init_profile(profile)
@@ -199,20 +181,18 @@ def show(type, name, explore, view):
         attributes = metrics_layer.get_model(name)
     elif type == "connection":
         attributes = metrics_layer.get_connection(name)
-    elif type == "explore":
-        attributes = metrics_layer.get_explore(name)
     elif type == "view":
-        attributes = metrics_layer.get_view(name, explore_name=explore)
+        attributes = metrics_layer.get_view(name)
     elif type == "field":
-        attributes = metrics_layer.get_field(name, view_name=view, explore_name=explore)
+        attributes = metrics_layer.get_field(name, view_name=view)
     elif type == "dimension":
-        attributes = metrics_layer.get_dimension(name, view_name=view, explore_name=explore)
+        attributes = metrics_layer.get_dimension(name, view_name=view)
     elif type == "metric":
-        attributes = metrics_layer.get_metric(name, view_name=view, explore_name=explore)
+        attributes = metrics_layer.get_metric(name, view_name=view)
     else:
         click.echo(
             f"Could not find the type {type}, please use one of the options: "
-            "models, connections, explores, views, fields, metrics, dimensions"
+            "models, connections, views, fields, metrics, dimensions"
         )
 
     if attributes:
